==> nifi-2.0.0-source-release.zip: nifi-2.0.0/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/flow-designer/ui/canvas/canvas-routing.module.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { Canvas } from './canvas.component';
import { AdvancedUi } from '../../../../ui/common/advanced-ui/advanced-ui.component';
import { processorAdvancedUiParamsResolver } from '../../service/resolver/processor-advanced-ui-params.resolver';
import { ComponentType } from 'libs/shared/src';

const routes: Routes = [
    {
        path: `${ComponentType.Processor}/:id/advanced`,
        resolve: { advancedUiParams: processorAdvancedUiParamsResolver },
        component: AdvancedUi
    },
    {
        path: '',
        component: Canvas,
        children: [
            { path: 'bulk/:ids', component: Canvas },
            { path: 'edit', component: Canvas },
            {
                path: 'history',
                component: Canvas
            },
            {
                path: ':type/:id',
                component: Canvas,
                children: [
                    { path: 'edit', component: Canvas },
                    { path: 'history', component: Canvas }
                ]
            }
        ]
    }
];

@NgModule({
    imports: [RouterModule.forChild(routes)],
    exports: [RouterModule]
})
export class CanvasRoutingModule {}

==> nifi-2.7.1-source-release.zip: nifi-2.7.1/nifi-frontend/src/main/frontend/apps/nifi/src/app/pages/flow-designer/ui/canvas/canvas-routing.module.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { Canvas } from './canvas.component';
import { AdvancedUi } from '../../../../ui/common/advanced-ui/advanced-ui.component';
import { processorAdvancedUiParamsResolver } from '../../service/resolver/processor-advanced-ui-params.resolver';
import { ComponentType } from '@nifi/shared';

const routes: Routes = [
    {
        path: `${ComponentType.Processor}/:id/advanced`,
        resolve: { advancedUiParams: processorAdvancedUiParamsResolver },
        component: AdvancedUi
    },
    {
        path: '',
        component: Canvas,
        children: [
            { path: 'bulk/:ids', component: Canvas },
            { path: 'edit', component: Canvas },
            {
                path: 'history',
                component: Canvas
            },
            {
                path: ':type/:id',
                component: Canvas,
                children: [
                    { path: 'edit', component: Canvas },
                    { path: 'history', component: Canvas }
                ]
            }
        ]
    }
];

@NgModule({
    imports: [RouterModule.forChild(routes)],
    exports: [RouterModule]
})
export class CanvasRoutingModule {}
